==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage invalid" : "Mesto shrambe ni veljavno",
    "Unknown error" : "Neznana napaka",
    "All files" : "Vse datoteke",
    "Recent" : "Nedavne",
    "Favorites" : "Priljubljene",
    "File could not be found" : "Datoteke ni mogoče najti",
    "Move or copy" : "Premakni ali kopiraj",
    "Download" : "Prejmi",
    "Delete" : "Izbriši",
    "Home" : "Začetni pogled",
    "Close" : "Zapri",
    "Could not create folder \"{dir}\"" : "Mape »{dir}« ni mogoče ustvariti.",
    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "Processing files …" : "Poteka obdelava datotek ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Datoteke {filename} ni mogoče poslati, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa »{dir}« ne obstaja več.",
    "Not enough free space" : "Ni dovolj prostora",
    "An unknown error has occurred" : "Prišlo je do neznane napake!",
    "Uploading …" : "Poteka pošiljanje ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Pošiljate te vrste predmeta ni podprto.",
    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
    "Actions" : "Dejanja",
    "Rename" : "Preimenuj",
    "Copy" : "Kopiraj",
    "Choose target folder" : "Izbor ciljne mape",
    "Open" : "Odpri",
    "Delete file" : "Izbriši datoteko",
    "Delete folder" : "Izbriši mapo",
    "Disconnect storage" : "Odklopi shrambo",
    "Unshare" : "Prekini souporabo",
    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
    "Files" : "Datoteke",
    "Details" : "Podrobnosti",
    "Select" : "Izbor",
    "Pending" : "Na čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "Could not move \"{file}\", target exists" : "Datoteke »{file}« ni mogoče premakniti, ker na ciljnem mestu z istim imenom že obstaja.",
    "Could not move \"{file}\"" : "Datoteke »{file}« ni mogoče premakniti",
    "copy" : "kopija",
    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja.",
    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
    "{newName} already exists" : "Ime {newName} že obstaja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberati je treba drugačno ime.",
    "Could not rename \"{fileName}\"" : "Datoteke »{fileName}« ni mogoče preimenovati",
    "Could not create file \"{file}\"" : "Datoteke »{file}« ni mogoče ustvariti.",
    "Could not create file \"{file}\" because it already exists" : "Datoteke »{file}« ni mogoče ustvariti, ker datoteka z istim imenom že obstaja.",
    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape »{dir}«, ker ta že obstaja",
    "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "_including %n hidden_::_including %n hidden_" : ["Vključujoč %n skrit","Vključujoč %n skrita","Vključujoč %n skritih","Vključujoč %n skritih"],
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
    "New" : "Novo",
    "Select file range" : "Izbor obsega datotek",
    "{used} of {quota} used" : "{used} od {quota} uporabljeno",
    "{used} used" : "Uporabljeno {used}·",
    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom »{filter}«","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "View in folder" : "Pokaži v mapi",
    "Copied!" : "Kopirano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
    "Path" : "Pot",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "You can only favorite a single file or folder at a time" : "Kot priljubljeno je mogoče naenkrat označiti le eno datoteko ali mapo.",
    "New folder" : "Nova mapa",
    "Upload file" : "Pošlji datoteko",
    "Not favorited" : "Ni priljubljeno",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "Added to favorites" : "Dodano med priljubljene",
    "Removed from favorites" : "Odstranjeno iz priljubljenih",
    "You added {file} to your favorites" : "Med priljubljene dodate datoteko {file}",
    "You removed {file} from your favorites" : "Odstranite datoteko {file} od priljubljenih",
    "File changes" : "Spremembe datoteke",
    "Created by {user}" : "{user} ustvari predmet",
    "Changed by {user}" : "{user} spremeni predmet",
    "Deleted by {user}" : "{user} izbriše predmet",
    "Restored by {user}" : "{user} obnovi predmet",
    "Renamed by {user}" : "{user} preimenuje predmet",
    "Moved by {user}" : "{user} premakne predmet",
    "\"remote user\"" : "»oddaljeni uporabnik«",
    "You created {file}" : "Ustvarite datoteko ali mapo {file}",
    "You created an encrypted file in {file}" : "Ustvarite šifrirano datoteko v {file}",
    "{user} created {file}" : "{user} ustvari datoteko {file}",
    "{user} created an encrypted file in {file}" : "{user} ustvari šifrirano datoteko v {file}",
    "{file} was created in a public folder" : "Datoteka {file} je ustvarjena v javni mapi",
    "You changed {file}" : "Spremenite datoteko {file}",
    "You changed an encrypted file in {file}" : "Spremenite šifrirano datoteko v {file}",
    "{user} changed {file}" : "{user} spremeni datoteko {file}",
    "{user} changed an encrypted file in {file}" : "Uporabnik {user} spremeni šifrirano datoteko {file}",
    "You deleted {file}" : "Izbrišete datoteko {file}",
    "You deleted an encrypted file in {file}" : "Izbrišete šifrirano datoteko {file}",
    "{user} deleted {file}" : "{user} izbriše datoteko {file}",
    "{user} deleted an encrypted file in {file}" : "{user} izbriše šifrirano datoteko {file}",
    "You restored {file}" : "Obnovite datoteko {file}",
    "{user} restored {file}" : "{user} obnovi datoteko {file}",
    "You renamed {oldfile} to {newfile}" : "Preimenujete datoteko {oldfile} v {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} preimenuje datoteko {oldfile} v {newfile}",
    "You moved {oldfile} to {newfile}" : "Premaknete datoteko {oldfile} v {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} premakne datoteko {oldfile} v {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila, ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datoteka ali mapa je bila <strong>spremenjena</strong> ali <strong>preimenovana</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Ustvarjena</strong>je nova datoteka ali mapa",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je bila <strong>izbrisana</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih</strong> datotek <em>(le za pretok)</em>",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je bila <strong>obnovljena</strong>",
    "Unlimited" : "Neomejeno",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "Accept" : "Sprejmi",
    "Reject" : "Zavrni",
    "Ownership transfer failed" : "Prenos lastništva ni uspel",
    "File Management" : "Upravljanje datotek",
    "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
    "Change" : "Spremeni",
    "New owner" : "Nov lastnik",
    "Search users" : "Iskanje uporabnikov",
    "Choose a file or folder to transfer" : "Izbor datoteke ali mape za prenos",
    "Transfer" : "Prenos",
    "Transfer {path} to {userid}" : "Prenesi {path} uporabniku {userid}",
    "Invalid path selected" : "Izbrana je neveljavna pot",
    "Ownership transfer request sent" : "Zahtevek prenosa lastništva poslan",
    "Tags" : "Oznake",
    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
    "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
    "%s used" : "Uporabljeno %s",
    "%s%% of %s used" : "Uporabljeno %s%% od %s",
    "%1$s of %2$s used" : "Uporabljeno %1$s od %2$s",
    "Settings" : "Nastavitve",
    "Show hidden files" : "Pokaži skrite datoteke",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Naslov omogoča dostop do datotek prek <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">WebDAV</a>.",
    "Toggle grid view" : "Preklopi mrežni pogled",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
    "Deleted files" : "Izbrisane datoteke",
    "Shares" : "Souporaba",
    "Shared with others" : "V souporabi  z drugimi",
    "Shared with you" : "V skupni rabi z vami",
    "Shared by link" : "V souporabi prek povezave",
    "Deleted shares" : "Izbrisana mesta souporabe",
    "Pending shares" : "Mesta souporabe na čakanju",
    "Text file" : "Besedilna datoteka",
    "New text file.txt" : "nova_datoteka.txt",
    "%s of %s used" : "Uporabljeno %s od %s",
    "%1$s%% of %2$s used" : "Uporabljeno %1$s%% od %2$s"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/sl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Storage invalid" : "Mesto shrambe ni veljavno",
    "Unknown error" : "Neznana napaka",
    "File could not be found" : "Datoteke ni mogoče najti",
    "Move or copy" : "Premakni ali kopiraj",
    "Download" : "Prejmi",
    "Delete" : "Izbriši",
    "Home" : "Začetni pogled",
    "Close" : "Zapri",
    "Favorites" : "Priljubljene",
    "Could not create folder \"{dir}\"" : "Mape »{dir}« ni mogoče ustvariti.",
    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
    "Upload cancelled." : "Pošiljanje je preklicano.",
    "Processing files …" : "Poteka obdelava datotek ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Datoteke {filename} ni mogoče poslati, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa »{dir}« ne obstaja več.",
    "Not enough free space" : "Ni dovolj prostora",
    "An unknown error has occurred" : "Prišlo je do neznane napake!",
    "Uploading …" : "Poteka pošiljanje ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Pošiljate te vrste predmeta ni podprto.",
    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
    "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
    "Actions" : "Dejanja",
    "Rename" : "Preimenuj",
    "Copy" : "Kopiraj",
    "Choose target folder" : "Izbor ciljne mape",
    "Open" : "Odpri",
    "Delete file" : "Izbriši datoteko",
    "Delete folder" : "Izbriši mapo",
    "Disconnect storage" : "Odklopi shrambo",
    "Leave this share" : "Zapusti to mesto souporabe",
    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
    "Files" : "Datoteke",
    "Details" : "Podrobnosti",
    "Select" : "Izbor",
    "Pending" : "Na čakanju ...",
    "Unable to determine date" : "Ni mogoče določiti datuma",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "Could not move \"{file}\", target exists" : "Datoteke »{file}« ni mogoče premakniti, ker na ciljnem mestu z istim imenom že obstaja.",
    "Could not move \"{file}\"" : "Datoteke »{file}« ni mogoče premakniti",
    "copy" : "kopija",
    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja.",
    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
    "{newName} already exists" : "Ime {newName} že obstaja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je že v uporabi v mapi \"{dir}\". Izberati je treba drugačno ime.",
    "Could not rename \"{fileName}\"" : "Datoteke »{fileName}« ni mogoče preimenovati",
    "Could not create file \"{file}\"" : "Datoteke »{file}« ni mogoče ustvariti.",
    "Could not create file \"{file}\" because it already exists" : "Datoteke »{file}« ni mogoče ustvariti, ker datoteka z istim imenom že obstaja.",
    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape »{dir}«, ker ta že obstaja",
    "Could not fetch file details \"{file}\"" : "Ni mogoče pridobiti podrobnosti datoteke »{file}«.",
    "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
    "Enter more than two characters to search in other folders" : "Vpišite več kot dva znaka za iskanje po drugih mapah",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
    "{dirs} and {files}" : "{dirs} in {files}",
    "_including %n hidden_::_including %n hidden_" : ["vključujoč %n skrite","vključujoč %n skritih","vključujoč %n skritih","vključujoč %n skritih"],
    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
    "New" : "Novo",
    "Select file range" : "Izbor obsega datotek",
    "{used} of {quota} used" : "{used} od {quota} uporabljeno",
    "{used} used" : "Uporabljeno {used}·",
    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Skupinska mapa »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "Zunanja shramba »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Shramba uporabnika {owner} je do konca zasedena ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinska mapa »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Zunanja shramba »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["se sklada s filtrom »{filter}«","se skladata s filtrom '{filter}'","se skladajo s filtrom '{filter}'","se skladajo s filtrom '{filter}'"],
    "View in folder" : "Pokaži v mapi",
    "Copied!" : "Kopirano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
    "Path" : "Pot",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Favorited" : "Označeno kot priljubljeno",
    "Favorite" : "Priljubljene",
    "You can only favorite a single file or folder at a time" : "Kot priljubljeno je mogoče naenkrat označiti le eno datoteko ali mapo.",
    "New folder" : "Nova mapa",
    "Upload file" : "Pošlji datoteko",
    "Recent" : "Nedavne",
    "Not favorited" : "Ni priljubljeno",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Add to favorites" : "Dodaj med priljubljene",
    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
    "Added to favorites" : "Dodano med priljubljene",
    "Removed from favorites" : "Odstranjeno iz priljubljenih",
    "You added {file} to your favorites" : "Med priljubljene dodate datoteko {file}",
    "You removed {file} from your favorites" : "Odstranite datoteko {file} od priljubljenih",
    "File changes" : "Spremembe datoteke",
    "Created by {user}" : "{user} ustvari predmet",
    "Changed by {user}" : "{user} spremeni predmet",
    "Deleted by {user}" : "{user} izbriše predmet",
    "Restored by {user}" : "{user} obnovi predmet",
    "Renamed by {user}" : "{user} preimenuje predmet",
    "Moved by {user}" : "{user} premakne predmet",
    "\"remote user\"" : "»Oddaljen uporabnik«",
    "You created {file}" : "Ustvarite datoteko ali mapo {file}",
    "You created an encrypted file in {file}" : "Ustvarite šifrirano datoteko v {file}",
    "{user} created {file}" : "{user} ustvari datoteko {file}",
    "{user} created an encrypted file in {file}" : "{user} ustvari šifrirano datoteko v {file}",
    "{file} was created in a public folder" : "Datoteka {file} je ustvarjena v javni mapi",
    "You changed {file}" : "Spremenite datoteko {file}",
    "You changed an encrypted file in {file}" : "Spremenite šifrirano datoteko v {file}",
    "{user} changed {file}" : "{user} spremeni datoteko {file}",
    "{user} changed an encrypted file in {file}" : "Uporabnik {user} spremeni šifrirano datoteko {file}",
    "You deleted {file}" : "Izbrišete datoteko {file}",
    "You deleted an encrypted file in {file}" : "Izbrišete šifrirano datoteko {file}",
    "{user} deleted {file}" : "{user} izbriše datoteko {file}",
    "{user} deleted an encrypted file in {file}" : "{user} izbriše šifrirano datoteko {file}",
    "You restored {file}" : "Obnovite datoteko {file}",
    "{user} restored {file}" : "{user} obnovi datoteko {file}",
    "You renamed {oldfile} to {newfile}" : "Preimenujete datoteko {oldfile} v {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} preimenuje datoteko {oldfile} v {newfile}",
    "You moved {oldfile} to {newfile}" : "Premaknete datoteko {oldfile} v {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} premakne datoteko {oldfile} v {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila, ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
    "A file or folder has been <strong>changed</strong>" : "Datoteka ali mapa je <strong>spremenjena</strong>.",
    "A favorite file or folder has been <strong>changed</strong>" : "Priljublena datoteka ali mapa je bila <strong>spremenjena</strong>",
    "All files" : "Vse datoteke",
    "Unlimited" : "Neomejeno",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "Accept" : "Sprejmi",
    "Reject" : "Zavrni",
    "Incoming ownership transfer from {user}" : "Vpisana je zahteva za prenos lastništva uporabnika {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ali želite sprejeti pot {path}?\n\nOpomba: po sprejetju lahko prenos traja tudi več kot 1 uro.",
    "Ownership transfer failed" : "Prenos lastništva je spodletel",
    "Your ownership transfer of {path} to {user} failed." : "Prenos vašega lastništva {path} na {user} je spodletelo",
    "The ownership transfer of {path} from {user} failed." : "Prenos lastništva {path} na {user} je spodletelo",
    "Ownership transfer done" : "Prenos lastništva je uspešno končan",
    "Your ownership transfer of {path} to {user} has completed." : "Prenos vašega lastništva {path} na {user} je končano",
    "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva {path} na {user} je končano",
    "in %s" : "v %s",
    "File Management" : "Upravljanje datotek",
    "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
    "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
    "Change" : "Spremeni",
    "New owner" : "Nov lastnik",
    "Search users" : "Iskanje uporabnikov",
    "Choose a file or folder to transfer" : "Izbor datoteke ali mape za prenos",
    "Transfer" : "Prenos",
    "Transfer {path} to {userid}" : "Prenesi pot {path} k uporabniku {userid}",
    "Invalid path selected" : "Izbrana je neveljavna pot",
    "Ownership transfer request sent" : "Zahteva za prenos lastništva je poslana",
    "Cannot transfer ownership of a file or folder you don't own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
    "Tags" : "Oznake",
    "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
    "%s used" : "Uporabljeno %s",
    "%s%% of %s used" : "Uporabljeno %s%% od %s",
    "%1$s of %2$s used" : "Uporabljeno %1$s od %2$s",
    "Settings" : "Nastavitve",
    "Show hidden files" : "Pokaži skrite datoteke",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Uporabite ta naslov za dostop do datotek prek WebDAV",
    "Toggle grid view" : "Preklopi mrežni pogled",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
    "Deleted files" : "Izbrisane datoteke",
    "Shares" : "Souporaba",
    "Shared with others" : "V souporabi  z drugimi",
    "Shared with you" : "V skupni rabi z vami",
    "Shared by link" : "V souporabi prek povezave",
    "Deleted shares" : "Izbrisana mesta souporabe",
    "Pending shares" : "Predmeti za souporabo na čakanju",
    "Text file" : "Besedilna datoteka",
    "New text file.txt" : "nova_datoteka.txt",
    "Unshare" : "Prekini souporabo",
    "This group folder is full, files can not be updated or synced anymore!" : "Ta skupinska mapa je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
    "This external storage is full, files can not be updated or synced anymore!" : "Ta zunanja shramba je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Shramba uporabnika {owner} je polna ({usedSpacePercent}%).",
    "This group folder is almost full ({usedSpacePercent}%)" : "Ta skupinska mapa za shranjevanje je skoraj do konca zasedena ({usedSpacePercent}%)",
    "This external storage is almost full ({usedSpacePercent}%)" : "Zunaji prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Prostor za shranjevanje je skoraj do konca zaseden ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datoteka ali mapa je bila <strong>spremenjena</strong> ali <strong>preimenovana</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Ustvarjena</strong> je nova datoteka ali mapa",
    "A file or folder has been <strong>deleted</strong>" : "Datoteka ali mapa je bila <strong>izbrisana</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Omeji obvestila o ustvarjanju in spreminjanju <strong>najpogosteje uporabljenih</strong> datotek <em>(le za pretok)</em>",
    "A file or folder has been <strong>restored</strong>" : "Datoteka ali mapa je bila <strong>obnovljena</strong>",
    "Cannot transfter ownership of a file or folder you don't own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Naslov omogoča dostop do datotek prek <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">WebDAV</a>."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
